@@ -1807,13 +1807,15 @@ ews_refresh_info_sync (CamelFolder *folder,
 	id = camel_ews_store_summary_get_folder_id_from_name (
 		ews_store->summary, full_name);
 
+	camel_operation_push_message (cancellable, _("Refreshing folder '%s'"), camel_folder_get_display_name (folder));
+
 	/* Sync folder items does not return the fields ToRecipients,
 	 * CCRecipients. With the item_type unknown, its not possible
 	 * to fetch the right properties which are valid for an item type.
 	 * Due to these reasons we just get the item ids and its type in
 	 * SyncFolderItem request and fetch the item using the
 	 * GetItem request. */
-	sync_state = ((CamelEwsSummary *) folder->summary)->sync_state;
+	sync_state = camel_ews_summary_dup_sync_state ((CamelEwsSummary *) folder->summary);
 	do {
 		GSList *items_created = NULL, *items_updated = NULL;
 		GSList *items_deleted = NULL;
@@ -1825,8 +1827,8 @@ ews_refresh_info_sync (CamelFolder *folder,
 
 		if (g_error_matches (local_error, EWS_CONNECTION_ERROR, EWS_CONNECTION_ERROR_INVALIDSYNCSTATEDATA)) {
 			g_clear_error (&local_error);
-			g_free (((CamelEwsSummary *) folder->summary)->sync_state);
-			((CamelEwsSummary *) folder->summary)->sync_state = NULL;
+			camel_ews_summary_set_sync_state ((CamelEwsSummary *) folder->summary, NULL);
+			g_free (sync_state);
 			sync_state = NULL;
 			ews_folder_forget_all_mails (ews_folder);
 
@@ -1868,8 +1870,7 @@ ews_refresh_info_sync (CamelFolder *folder,
 		camel_ews_store_summary_set_folder_unread (ews_store->summary, id, unread);
 		camel_ews_store_summary_save (ews_store->summary, NULL);
 
-		g_free (((CamelEwsSummary *) folder->summary)->sync_state);
-		((CamelEwsSummary *) folder->summary)->sync_state = sync_state;
+		camel_ews_summary_set_sync_state ((CamelEwsSummary *) folder->summary, sync_state);
 
 		camel_folder_summary_touch (folder->summary);
 
@@ -1884,6 +1885,8 @@ ews_refresh_info_sync (CamelFolder *folder,
 		}
 	} while (!local_error && !includes_last_item && !g_cancellable_is_cancelled (cancellable));
 
+	camel_operation_pop_message (cancellable);
+
 	if (camel_folder_change_info_changed (change_info)) {
 		camel_folder_summary_touch (folder->summary);
 		camel_folder_summary_save_to_db (folder->summary, NULL);
@@ -1900,9 +1903,9 @@ ews_refresh_info_sync (CamelFolder *folder,
 	g_mutex_lock (&priv->state_lock);
 	priv->refreshing = FALSE;
 	g_mutex_unlock (&priv->state_lock);
-	if (sync_state != ((CamelEwsSummary *) folder->summary)->sync_state)
-		g_free (sync_state);
+
 	g_object_unref (cnc);
+	g_free (sync_state);
 	g_free (id);
 
 	return !local_error;
@@ -1946,7 +1949,7 @@ ews_append_message_sync (CamelFolder *folder,
 		g_free (folder_id);
 		g_set_error (
 			error, CAMEL_ERROR, CAMEL_ERROR_GENERIC,
-			_("Cant perform actions on the folder while in offline mode"));
+			_("Cannot perform actions on the folder while in offline mode"));
 		return FALSE;
 	}
 
@@ -2165,6 +2168,14 @@ ews_transfer_messages_to_sync (CamelFolder *source,
 	return !local_error;
 }
 
+static void
+ews_prepare_content_refresh (CamelFolder *folder)
+{
+	g_return_if_fail (CAMEL_IS_EWS_FOLDER (folder));
+
+	camel_ews_summary_set_sync_state (CAMEL_EWS_SUMMARY (folder->summary), NULL);
+}
+
 static gboolean
 ews_delete_messages_from_server (CamelEwsStore *ews_store,
 				 const GSList *deleted_items,
@@ -2550,6 +2561,7 @@ camel_ews_folder_class_init (CamelEwsFolderClass *class)
 	folder_class->synchronize_sync = ews_synchronize_sync;
 	folder_class->expunge_sync = ews_expunge_sync;
 	folder_class->transfer_messages_to_sync = ews_transfer_messages_to_sync;
+	folder_class->prepare_content_refresh = ews_prepare_content_refresh;
 	folder_class->get_filename = ews_get_filename;
 }
 
